@@ -1,11 +1,13 @@
 use byteorder::NetworkEndian;
 
 use crate::io::BufMut;
+use crate::postgres::protocol::Write;
 
+#[derive(Debug)]
 pub struct SslRequest;
 
-impl SslRequest {
-    pub fn encode(buf: &mut Vec<u8>) {
+impl Write for SslRequest {
+    fn write(&self, buf: &mut Vec<u8>) {
         // packet length: 8 bytes including self
         buf.put_u32::<NetworkEndian>(8);
         // 1234 in high 16 bits, 5679 in low 16
@@ -15,10 +17,8 @@ impl SslRequest {
 
 #[test]
 fn test_ssl_request() {
-    use crate::io::Buf;
-
     let mut buf = Vec::new();
-    SslRequest::encode(&mut buf);
+    SslRequest.write(&mut buf);
 
     assert_eq!(&buf, b"\x00\x00\x00\x08\x04\xd2\x16/");
 }
